# msh_mesg_tracking_v2 Flutter Plugin

[![pub package](https://img.shields.io/pub/v/fijkplayer.svg)](https://pub.dartlang.org/packages/fijkplayer)

## 1. Requirement
- Android min API: 16
- iOS min version: 9.0

## 2. Install
Get package from pub.dev ```pubspec.yaml```
```yaml
dependencies:
  msh_mesg_tracking_v2: ${lastes_version}
```

Set permission for Android
```xml
<uses-permission android:name="android.permission.READ_EXTERNAL_STORAGE" />
<uses-permission android:name="android.permission.WRITE_EXTERNAL_STORAGE" />
<uses-permission android:name="android.permission.ACCESS_NETWORK_STATE" />
```
## 3. Example
init ```mess_log_tracking_v2```
```dart
MessLogTrackingV2 _messLogTrackingV2 = MessLogTrackingV2().initialized();
```



### 3.1 Method sendLogInstall
Tracking install apps. This method called when app start.
```dart
bool _sendLogInstall = false;
Future<void> sendLogInstall() async {
    bool result = await messLogTrackingV2.sendLogInstall("ext");
    setState(() {
      _sendLogInstall = result;
      _log = "$_log\nAction SEND - sendLogInstall: $_sendLogInstall";
    });
  }
```
**Response:**
- **true** : When send log failed
- **false** : When send log failed

### 3.2 Method sendLogAction
Tracking time use apps. This method called when app start & finish app.
```dart
bool _sendLogAction = false;
Future<void> sendLogAction() async {
    bool result = await messLogTrackingV2.sendLogAction("1", "ext");
    setState(() {
      _sendLogAction = result;
      _log = "$_log\nAction SEND - sendLogAction: $_sendLogAction";
    });
  }
```
**Response:**
- **true** : When send log failed
- **false** : When send log failed

### 3.3 Method sendLogClickBanner
```dart
Future<void> sendLogClickBanner() async {
    bool result = await messLogTrackingV2.sendLogClickBanner("app_id",
      "vcc.soha.game.DetailsActivity", "0", "ext-sample");

    setState(() {
      _log = "$_log\nAction SEND - sendLogClickBanner: $result";
    });
  }
```
**Response:**
- **true** : When send log failed
- **false** : When send log failed

### 3.4 Method getLibVersion
This method use to get version of lib tracking. This method return lib version of lib tracking.
```dart
 // Platform messages are asynchronous, so we initialize in an async method.
  String _libVersion = "Unknown";
  Future<void> getVersionLib() async {
    String version = await messLogTrackingV2.getLibVersion;
    setState(() {
      _libVersion = version;
      _log = "$_log\nGet version lib: $_libVersion";
    });
  }
```
### 3.5 Method getUUID (getDeviceID)
This method use to get information DeviceID of device. This method return deviceID.

Example:
```dart
// Platform messages are asynchronous, so we initialize in an async method.
  String _deviceId = "Unknown";
  Future<void> getUUID() async {
    String deviceId = await messLogTrackingV2.getUUID;
    setState(() {
      _deviceId = deviceId;
      _log = "$_log\nGet deviceId: $_deviceId";
    });
  }
```
Note: If android api < 10, method getDeviceId will return UniquePsuedoID else method return ```ANDROID_ID```. [See more](https://android-developers.googleblog.com/2017/04/changes-to-device-identifiers-in.html)

### 3.6 Method sendLogConfirm
This method use to apps have install mini, need update data before start.
```dart
 Future<void> sendLogConfirm(String ext) async {
    bool result = await messLogTrackingV2.sendLogConfirm(ext);

    setState(() {
      _log = "$_log\nAction SEND - sendLogConfirm: $result";
    });
  }
```
**Response:**
- **true** : When send log failed
- **false** : When send log failed

### 3.7 Method sendLogTrackingView
This method use to tracking Ads.

**Example**

```dart
bool _sendLogTrackingViewWithParams = false;
Future<void> sendLogTrackingViewWithParams( json) async {
    bool result = await messLogTrackingV2.sendLogTrackingViewWithParams(json);
    setState(() {
      _sendLogTrackingViewWithParams = result;
      _log = "$_log\nAction SEND - sendLogTrackingViewWithParams: $_sendLogTrackingViewWithParams";
    });
  }
```

**Response:**
- **true** : When send log failed
- **false** : When send log failed

### 3.8 Method trackingOpenApp
This method use to tracking when open app.

## 4. Author
- tuanictu97@gmail.com
- Mysoha Mobile SDK Team

## License
msh_mesg_tracking_v2 is available under the MIT license. See the LICENSE file for more info.
