import 'package:flutter/material.dart';
import 'dart:async';
import 'package:messlogv2/mess_log_tracking_v2.dart';
import 'package:messlogv2/src/model/params_log.dart';
import 'package:messlogv2/src/model/cov_type.dart';
import 'package:messlogv2/src/model/log_type.dart';

void main() {
  runApp(MyApp());
}

class MyApp extends StatefulWidget {
  @override
  _MyAppState createState() => _MyAppState();
}

class _MyAppState extends State<MyApp> {
  MessLogTrackingV2 messLogTrackingV2 = MessLogTrackingV2().initialized();
  String _deviceId = "Unknown";
  String _libVersion = "Unknown";
  String _log = "LogEvent MessLogTrackingV2 flutter";

  @override
  void initState() {
    super.initState();
    getVersionLib();
    sendLogAction();
    getUUID();
    sendLogConfirm("sample send log confirm flutter");
    sendLogTrackingView();
    sendLogInstall();
    sendLogClickBanner();
    sendLogTrackingViewWithParams();
  }

  // Platform messages are asynchronous, so we initialize in an async method.
  Future<void> getUUID() async {
    String deviceId = await messLogTrackingV2.getUUID;

    setState(() {
      _deviceId = deviceId;
      _log = "$_log\nGet deviceId: $_deviceId";
    });
  }

  // Platform messages are asynchronous, so we initialize in an async method.
  Future<void> getVersionLib() async {
    String version = await messLogTrackingV2.getLibVersion;

    setState(() {
      _libVersion = version;
      _log = "$_log\nGet version lib: $_libVersion";
    });
  }

  Future<void> sendLogInstall() async {
    bool result = await messLogTrackingV2.sendLogInstall("ext");

    setState(() {
      _log = "$_log\nAction SEND - sendLogInstall: $result";
    });
  }

  Future<void> sendLogAction() async {
    bool result = await messLogTrackingV2.sendLogAction("1", "ext");

    setState(() {
      _log = "$_log\nAction SEND - sendLogAction: $result";
    });
  }

  Future<void> sendLogConfirm(String ext) async {
    bool result = await messLogTrackingV2.sendLogConfirm(ext);

    setState(() {
      _log = "$_log\nAction SEND - sendLogConfirm: $result";
    });
  }

  Future<void> sendLogTrackingView() async {
    bool result = await messLogTrackingV2.sendLogTrackingView(
      "domain",
      "rurl",
      "vid",
      "vid",
      COV_TYPE.VIEW,
      LOG_TYPE.NONE,
      "pspid",
      "pspid",
      "algid",
      "ext"
    );

    setState(() {
      _log = "$_log\nAction SEND - sendLogTrackingView: $result";
    });
  }

  Future<void> sendLogTrackingViewWithParams() async {
    ParamsLog paramsLog = ParamsLog(
      algid: "algid sample flutter",
      domain: "kenh19-flutter",
      cov: COV_TYPE.VIEW,
      ltype: LOG_TYPE.BOX_VIEW,
      vid: "Vid"
    );
    bool result = await messLogTrackingV2.sendLogTrackingViewWithParams(paramsLog);

    setState(() {
      _log = "$_log\nAction SEND - sendLogTrackingViewWithParams: $result";
    });
  }

  Future<void> sendLogClickBanner() async {
    bool result = await messLogTrackingV2.sendLogClickBanner("app_id",
      "vcc.soha.game.DetailsActivity", "0", "ext-sample");

    setState(() {
      _log = "$_log\nAction SEND - sendLogClickBanner: $result";
    });
  }



  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      debugShowCheckedModeBanner: false,
      home: Scaffold(
        appBar: AppBar(
          title: const Text('MessLogV2Tracking Example'),
        ),
        body: Center(
          child: Column(
            children: [
              Container(
                width: double.infinity,
                child: RaisedButton(
                  child: Text('Check'),
                  onPressed: _checkLog,
                ),
              ),
              Container(
                width: double.infinity,
                child: RaisedButton(
                  child: Text('Push'),
                  onPressed: _pushLog,
                ),
              ),
              Container(
                width: double.infinity,
                child: RaisedButton(
                  child: Text('Clear log'),
                  onPressed: _clearLog,
                ),
              ),
              Container(
                width: double.infinity,
                child: RaisedButton(
                  child: Text('Clear call record database'),
                  onPressed: _clearDatabase,
                ),
              ),
              Container(
                margin: const EdgeInsets.all(16),
                width: double.infinity,
                child: SingleChildScrollView(
                  scrollDirection: Axis.vertical,
                  child: Text('$_log'),
                ),
              )
            ],
          ),
        ),
      ),
    );
  }

  void _checkLog() {
    // do clear log

  }

  void _pushLog() {
    // do push log

  }

  void _clearLog() {
    setState(() {
      _log = "";
    });
  }

  void _clearDatabase() {
    setState(() {
      _log = "$_log\nAction Clear Database!";
    });
  }
}

