import 'package:flutter/services.dart';
import 'package:msh_mesg_tracking_v2/src/mess_log_v2_native.dart';
import 'package:msh_mesg_tracking_v2/src/model/model.dart';

class MessLogTrackingV2{
  MessLogV2Native _messLogV2Native;

  MessLogTrackingV2 initialized(){
    _messLogV2Native = MessLogV2Native();
    return this;
  }

  Future<String> get getLibVersion async{
    String version = await _messLogV2Native.getLibVersion;
    if(version != null && version.isNotEmpty){
      return version;
    }
    return "Unknown version";
  }

  Future<String> get getUUID async{
    String uuid = await _messLogV2Native.getUUID;
    if(uuid != null && uuid.isNotEmpty){
      return uuid;
    }
    return "Unknown UUID";
  }

  Future<bool> sendLogInstall(String ext) async{
    bool response = await _messLogV2Native.sendLogInstall(ext);
    if(response != null){
      return response;
    }
    return false;
  }

  Future<bool> sendLogAction(String isClose, String ext) async{
    bool response = await _messLogV2Native.sendLogAction(isClose, ext);
    if(response != null){
      return response;
    }
    return false;
  }

  Future<bool> sendLogConfirm(String ext) async{
    bool response = await _messLogV2Native.sendLogConfirm(ext);
    if(response != null){
      return response;
    }
    return false;
  }

  Future<bool> sendLogClickBanner(String appId, String org, String currentAction, String ext) async{
    bool response = await _messLogV2Native.sendLogClickBanner(appId, org, currentAction, ext);
    if(response != null){
      return response;
    }
    return false;
  }

  Future<bool> sendLogTrackingView(String domain, String curl, String rurl,
    String vid, COV_TYPE cov, LOG_TYPE ltype, String boxid, String dspid, String algid, String ext) async{
    String stringLtype;
    String stringCov;
    switch(ltype){
      case LOG_TYPE.NONE:
        stringLtype = "0";
        break;
      case LOG_TYPE.PAGE_VIEW:
        stringLtype = "1";
        break;
      case LOG_TYPE.RECV:
        stringLtype = "2";
        break;
      case LOG_TYPE.BOX_VIEW:
        stringLtype = "3";
        break;
    }
    switch(cov){
      case COV_TYPE.VIEW:
        stringCov = "0";
        break;
      case COV_TYPE.CLICK:
        stringCov = "1";
        break;
      case COV_TYPE.SCROLL:
        stringCov = "2";
        break;
    }
    bool response = await _messLogV2Native.sendLogTrackingViewV1(domain, curl, rurl, vid, stringCov, stringLtype,
    dspid, boxid, algid, ext);
    if(response != null){
      return response;
    }
    return false;
  }

  Future<bool> sendLogTrackingViewWithParams(ParamsLog paramsLog) async{
    bool response = await _messLogV2Native.sendLogTrackingViewV2(paramsLog);
    if(response != null){
      return response;
    }
    return false;
  }
}