import 'dart:async';
import 'package:flutter/services.dart';

import 'model/model.dart';

class MessLogV2Native {
  MethodChannel channel = const MethodChannel('mess_log_tracking_v2');

  Future<String> get getLibVersion async {
    String version = "Unknown version";
    final String result = await channel.invokeMethod('get_lib_version');
    if(result != null && result.isNotEmpty){
      version = result;
    }
    return version;
  }

  Future<String> get getUUID async {
    String uuid = "Unknown version";
    final String result = await channel.invokeMethod('get_device_id');
    if(result != null && result.isNotEmpty){
      uuid = result;
    }
    return uuid;
  }

  Future<bool> sendLogInstall(String ext) async {
    bool response = false;
    final bool result = await channel.invokeMethod('sendLogInstall',
        {'ext': ext});
    if(result != null){
      response = result;
    }
    return response;
  }

  Future<bool> sendLogConfirm(String ext) async {
    bool response = false;
    final bool result = await channel.invokeMethod('sendLogConfirm',
        {'ext': ext});
    if(result != null){
      response = result;
    }
    return response;
  }

  Future<bool> sendLogAction(String isClose, String ext) async {
    bool response = false;
    final bool result = await channel.invokeMethod('sendLogAction',
        {'is_close': isClose, 'ext': ext });
    if(result != null){
      response = result;
    }
    return response;
  }

  Future<bool> sendLogTrackingViewV1(String domain, String curl, rurl, vid, cov,
      ltype, boxid, dspid, algid, ext) async {
    bool response = false;
    final bool result = await channel.invokeMethod('sendLogTrackingViewV1',
        {'domain': domain, 'curl': curl, 'rurl': rurl,
          'vid': vid, 'cov': cov, 'ltype': ltype, 'boxid': boxid,
          'dspid': dspid, 'algid': algid, 'ext': ext});
    if(result != null){
      response = result;
    }
    return response;
  }

  Future<bool> sendLogClickBanner(String appId, String currentActivity,
      String currentAction, String ext) async {
    bool response = false;
    final bool result = await channel.invokeMethod('sendLogAction',
        {'app_id': appId, 'current_activity': currentActivity,
          'current_action': currentAction, 'ext': ext});
    if(result != null){
      response = result;
    }
    return response;
  }

  Future<bool> sendLogTrackingViewV2(ParamsLog paramsLog) async {
    bool response = false;
    
    //  final String domain;
    //   final String curl;
    //   final String rurl;
    //   final String vid;
    //   final COV_TYPE cov;
    //   final LOG_TYPE ltype;
    //   final String boxid;"
    //   final String dspid;
    //   final String algid;
    //   final String ext;

    String cov;
    String ltype;
    switch(paramsLog.ltype){
      case LOG_TYPE.NONE:
        ltype = "0";
        break;
      case LOG_TYPE.PAGE_VIEW:
        ltype = "1";
        break;
      case LOG_TYPE.RECV:
        ltype = "2";
        break;
      case LOG_TYPE.BOX_VIEW:
        ltype = "3";
        break;
    }

    switch(paramsLog.cov){
      case COV_TYPE.VIEW:
        cov = "0";
        break;
      case COV_TYPE.CLICK:
        cov = "1";
        break;
      case COV_TYPE.SCROLL:
        cov = "2";
        break;
    }

    final bool result = await channel.invokeMethod('sendLogTrackingViewV2',
        {'domain': paramsLog.domain, 'curl': paramsLog.curl, 'rurl': paramsLog.rurl, 'vid': paramsLog.vid, 
        'cov': cov, 'ltype': ltype, 'boxid': paramsLog.boxid, 'algid': paramsLog.algid, 'ext': paramsLog.ext});
    if(result != null){
      response = result;
    }
    return response;
  }
}
